summaryrefslogtreecommitdiffstats
path: root/kwin-styles/cde/config/config.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kwin-styles/cde/config/config.cpp')
-rw-r--r--kwin-styles/cde/config/config.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kwin-styles/cde/config/config.cpp b/kwin-styles/cde/config/config.cpp
index cf58377d..fcd2de42 100644
--- a/kwin-styles/cde/config/config.cpp
+++ b/kwin-styles/cde/config/config.cpp
@@ -13,18 +13,18 @@ extern "C" KDE_EXPORT TQObject* allocate_config( KConfig* conf, TQWidget* parent
/* NOTE:
* 'conf' is a pointer to the kwindecoration modules open kwin config,
* and is by default set to the "Style" group.
*
* 'parent' is the parent of the TQObject, which is a VBox inside the
- * Configure tab in kwindecoration
+ * Configure tab in twindecoration
*/
CdeConfig::CdeConfig( KConfig* conf, TQWidget* parent )
: TQObject( parent )
{
- cdeConfig = new KConfig("kwincderc");
- KGlobal::locale()->insertCatalogue("kwin_art_clients");
+ cdeConfig = new KConfig("twincderc");
+ KGlobal::locale()->insertCatalogue("twin_art_clients");
groupBox = new TQVBox( parent );
@@ -57,7 +57,7 @@ CdeConfig::CdeConfig( KConfig* conf, TQWidget* parent )
// connect( cbTitlebarButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotSelectionChanged()) );
connect( bgAlign, TQT_SIGNAL(clicked(int)), TQT_SLOT(slotSelectionChanged(int)) );
- // Make the widgets visible in kwindecoration
+ // Make the widgets visible in twindecoration
groupBox->show();
}
@@ -80,8 +80,8 @@ void CdeConfig::slotSelectionChanged( int )
emit changed();
}
-// Loads the configurable options from the kwinrc config file
-// It is passed the open config from kwindecoration to improve efficiency
+// Loads the configurable options from the twinrc config file
+// It is passed the open config from twindecoration to improve efficiency
void CdeConfig::load( KConfig* /*conf*/ )
{
cdeConfig->setGroup("General");
@@ -99,7 +99,7 @@ void CdeConfig::load( KConfig* /*conf*/ )
}
-// Saves the configurable options to the kwinrc config file
+// Saves the configurable options to the twinrc config file
void CdeConfig::save( KConfig* /*conf*/ )
{
cdeConfig->setGroup("General");
@@ -13,18 +13,18 @@ extern "C" KDE_EXPORT TQObject* allocate_config( KConfig* conf, TQWidget* parent
/* NOTE:
- * 'conf' is a pointer to the kwindecoration modules open kwin config,
+ * 'conf' is a pointer to the twindecoration modules open twin config,
* and is by default set to the "Style" group.
*